import java.util.ArrayList;
import java.util.Random;
/**
 * The Wumpus world map
 * 
 * @author Malcolm
 * @version 20 Sep 2012
 */
public class Map
{
    public static final int NUM_ROOMS = 20; 
    private ArrayList<Room> myRooms;
    
    public Map() {
        
        myRooms = new ArrayList<Room>();
        // create the rooms
        for (int i = 0; i < NUM_ROOMS; i++) {
            Room r = new Room(i);
            myRooms.add(r);
        }
        
        // connect the outer ring
        // 0 - 1 - 2 - 3 - 4 - 0
        for (int i = 0; i < 5; i++) {
            Room r1 = myRooms.get(i);
            Room r2 = myRooms.get((i+1) % 5);
            
            r1.connectTo(r2);
            r2.connectTo(r1);
        }

        // connect the middle ring
        // 5 - 6 - 7 - 8 - 9 - 10 - 11 - 12 - 13 - 14 - 5
        for (int i = 5; i < 15; i++) {
            Room r1 = myRooms.get(i);
            Room r2 = myRooms.get((i-5 + 1) % 10 + 5);
            
            r1.connectTo(r2);
            r2.connectTo(r1);
        }
        
        // connect the inner ring
        // 15 - 16 - 17 - 18 - 19 - 15
        for (int i = 15; i < 20; i++) {
            Room r1 = myRooms.get(i);
            Room r2 = myRooms.get((i-15 + 1) % 5 + 15);
            
            r1.connectTo(r2);
            r2.connectTo(r1);
        }
        
        // connect the outer ring to the middle
        for (int i = 0; i < 5; i++) {
            Room r1 = myRooms.get(i);
            Room r2 = myRooms.get(i*2 + 5);
            
            r1.connectTo(r2);
            r2.connectTo(r1);
        }
        
        // connect the inner ring to the middle
        for (int i = 15; i < 20; i++) {
            Room r1 = myRooms.get(i);
            Room r2 = myRooms.get((i-15)*2 + 6);
            
            r1.connectTo(r2);
            r2.connectTo(r1);
        }        
        
        // two rooms with bats
        Room bats1 = getRandomRoom();
        Room bats2;
        
        do {
            bats2 = getRandomRoom();
        } while (bats1 == bats2);
        bats1.setHasBats(true);
        bats2.setHasBats(true);
        
        // one pit
        Room pit = getRandomRoom();
        pit.setHasPit(true);
                
        // one wumpus
        Room wumpus = getRandomRoom();
        wumpus.setHasWumpus(true);
    }
    
    public Room getRoom(int id) {
        return myRooms.get(id);
    }
    
    public Room getRandomRoom() {
        Random rng = new Random();
        int i = rng.nextInt(Map.NUM_ROOMS);        
        return myRooms.get(i);
    }
}
