import java.util.Random;
import java.util.ArrayList;

/**
 * Wumpus game player
 * 
 * @author Malcolm Ryan 
 * @version 20 Sep 2012
 */
public class Player
{
    private Map myMap;
    private Room myCurrentRoom;
    int myArrows;
    public static final int NUM_ARROWS = 3;
    
    public Player(Map map) {
        myMap = map;        
        myArrows = NUM_ARROWS;
        myCurrentRoom = null;

    }

    
    private Room readNeighbouringRoom() {        
        ArrayList<Room> neighbours = myCurrentRoom.getNeighbours();

        Room choice = null; 
        while (choice == null) {
        
            System.out.print("Choose [");
            for (int i = 0; i < neighbours.size(); i++) {
                if (i > 0) {
                    System.out.print(", ");
                }
                System.out.print(neighbours.get(i).getRoomID());
            }
            System.out.print("] ");
 
            Integer id = Input.readInt();
            if (id != null) {            
                for (Room r : neighbours) {                
                    if (r.getRoomID() == id) {
                        choice = r;
                    }
                }
            }        
        }
        
        return choice;
    }

    public boolean moveTo(Room room) {
        myCurrentRoom = room;
        return room.enter(this);
    }

    public boolean moveRandom() {
        Room r = myMap.getRandomRoom();
        return moveTo(r);
    }
    

    public boolean shoot(Room room) {
        boolean gameOver = room.shoot();
            
        myArrows--;
        if (!gameOver && myArrows == 0) {
            System.out.println("You are out of arrows!");
            gameOver = true;
        }
        return gameOver;
    }
    
    private boolean playTurn() {
        
        boolean gameOver = false;
        
        System.out.print("(M)ove or (S)hoot? ");
        char c = Input.readChar();
        
        if (c == 'M') {
            // move
            System.out.println("Which room do you want to move to?");
            Room room = readNeighbouringRoom();
            gameOver = moveTo(room);
        }
        else if (c == 'S') {
            System.out.println("Which room do you want to shoot to?");
            Room room = readNeighbouringRoom();
            gameOver = shoot(room);
        }
        
        return gameOver;
    }
    
    private void play() {
        System.out.println("Welcome to Wumpus World!");
        System.out.println();
        
        boolean gameOver = moveRandom();
        
        while (!gameOver) {
            gameOver = playTurn();            
        }
        
        System.out.println("GAME OVER!");
    }
    
    public static void main(String args[]) {
        Map map = new Map();
        Player player = new Player(map);
        player.play();
    }
    
}
